<?php
/*
 * patches/manifest.inc
 *
 * part of pfSense (https://www.pfsense.org)
 * Copyright (c) 2022-2023 Rubicon Communications, LLC (Netgate)
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

global $recommended_patches;
/*
 * Keep each patch block separate, do not attempt to combine/overlap entries to
 * save space.
 */
$recommended_patches = [
[
  'uniqid' => '15525',
  'versions' => ['24.03', '23.09.1', '2.7.2'],
  'descr' => 'Fix potential XSS in the file browser on diag_edit.php',
  'links' => [
      [ 'text' => 'pfSense-SA-24_05.webgui',
         'url' => 'https://docs.netgate.com/downloads/pfSense-SA-24_05.webgui.asc', ],
      [ 'text' => 'Redmine #15525',
         'url' => 'https://redmine.pfsense.org/issues/15525', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '15702',
  'versions' => ['24.03', '23.09.1', '2.7.2'],
  'descr' => 'Fix potential information disclosure due to misrouted DHCP server responses',
  'links' => [
      [ 'text' => 'Trigger a filter reload after applying to activate' ],
      [ 'text' => 'pfSense-SA-24_07.dhclient',
         'url' => 'https://docs.netgate.com/downloads/pfSense-SA-24_07.dhclient.asc', ],
      [ 'text' => 'Redmine #15702',
         'url' => 'https://redmine.pfsense.org/issues/15702', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '15778',
  'versions' => ['24.03', '23.09.1', '2.7.2'],
  'descr' => 'Fix potential stored XSS in Interface Groups',
  'links' => [
      [ 'text' => 'pfSense-SA-24_08.webgui',
         'url' => 'https://docs.netgate.com/downloads/pfSense-SA-24_08.webgui.asc', ],
      [ 'text' => 'Redmine #15778',
         'url' => 'https://redmine.pfsense.org/issues/15778', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'CVE-2024-6387-workaround',
  'versions' => ['24.03', '23.09.1', '2.7.2'],
  'descr' => 'Workaround for SSH CVE-2024-6387',
  'links' => [
      [ 'text' => 'After applying, restart the SSH Daemon or reboot.' ],
      [ 'text' => 'FreeBSD-SA-24:04.openssh',
         'url' => 'https://www.freebsd.org/security/advisories/FreeBSD-SA-24:04.openssh.asc', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '14083',
  'versions' => ['24.03'],
  'descr' => 'Fix boot failure when a LAGG interface or one of its members has MTU or MSS configured',
  'links' => [
      [ 'text' => 'Redmine #14083',
         'url' => 'https://redmine.pfsense.org/issues/14083', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '15449',
  'versions' => ['24.03'],
  'descr' => 'Fix IPsec VTI static routes not being added after boot',
  'links' => [
      [ 'text' => 'After applying, edit and save affected IPsec tunnels or reboot.' ],
      [ 'text' => 'Redmine #15449',
         'url' => 'https://redmine.pfsense.org/issues/15449', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '15430-24_03',
  'versions' => ['24.03'],
  'descr' => 'Automatically use floating states for IPsec rules',
  'links' => [
      [ 'text' => 'After applying, reload the filter or reboot.' ],
      [ 'text' => 'Redmine #15430',
         'url' => 'https://redmine.pfsense.org/issues/15430', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '27fc5a3020fe981b7a5bc98fc9b1660e8773fc7d',
  'versions' => ['24.03'],
  'descr' => 'Fix local CAs not being added to the Trust Store',
  'links' => [
      [ 'text' => 'After applying, edit and save a CA or reboot.' ],
      [ 'text' => 'Redmine #15440',
         'url' => 'https://redmine.pfsense.org/issues/15440', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '90c4a2fe6db1bafc8bb4bc038cf3e3664ac6db47',
  'versions' => ['24.03'],
  'descr' => 'Fix CLI password check exiting with a write access error for non-privileged users',
  'links' => [
      [ 'text' => 'Redmine #15442',
         'url' => 'https://redmine.pfsense.org/issues/15442', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '247909ff5387200fb31c76f13e7702a8fbdc06f4',
  'versions' => ['24.03'],
  'descr' => 'Fix DNS Forwarder ignoring "Use remote DNS Servers, ignore local DNS" setting',
  'links' => [
      [ 'text' => 'Redmine #15434',
         'url' => 'https://redmine.pfsense.org/issues/15434', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'b891c3a33aff74f4ded6176a78b22ed84821036a',
  'versions' => ['24.03'],
  'descr' => 'Show current boot method in the BIOS section of the System Information widget',
  'links' => [
      [ 'text' => 'Redmine #15422',
         'url' => 'https://redmine.pfsense.org/issues/15422', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '7cbbda697adeabca5eaad369099ea995a4c2cd42',
  'versions' => ['24.03'],
  'descr' => 'Fix inconsistency in CRL tab names in the Certificate Manager',
  'links' => [
      [ 'text' => 'Redmine #15454',
         'url' => 'https://redmine.pfsense.org/issues/15454', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '2adf7b8cde44a8e2f0f0cbb2a7f6c360e3bf4050',
  'versions' => ['23.09.1', '2.7.2'],
  'descr' => 'Fix Packet Capture not working on Tailscale interfaces',
  'links' => [
      [ 'text' => 'Redmine #15145',
         'url' => 'https://redmine.pfsense.org/issues/15145', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '12cbb18a93c1f78e05806b6d3c90511e8967f43f',
  'versions' => ['23.09.1', '2.7.2'],
  'descr' => 'Fix potential local file include via DNS Resolver Python Module Script include mechanism',
  'links' => [
      [ 'text' => 'pfSense-SA-24_01.webgui',
         'url' => 'https://docs.netgate.com/downloads/pfSense-SA-24_01.webgui.asc', ],
      [ 'text' => 'Redmine #15135',
         'url' => 'https://redmine.pfsense.org/issues/15135', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '6f59a7f9fdfe3703667819fcbbd8b6f8cbec0d9f',
  'versions' => ['23.09.1', '2.7.2'],
  'descr' => 'Fix potential stored XSS via services_acb_settings.php "frequency" paramter',
  'links' => [
      [ 'text' => 'pfSense-SA-24_02.webgui',
         'url' => 'https://docs.netgate.com/downloads/pfSense-SA-24_02.webgui.asc', ],
      [ 'text' => 'Redmine #15224',
         'url' => 'https://redmine.pfsense.org/issues/15224', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '15263-15264-combined',
  'versions' => ['23.09.1', '2.7.2'],
  'descr' => 'Fix potential XSS due to PHP error display formatting issues',
  'links' => [
      [ 'text' => 'After applying, reboot or use console/ssh menu options 11/16 to restart PHP and the GUI' ],
      [ 'text' => 'pfSense-SA-24_03.webgui',
         'url' => 'https://docs.netgate.com/downloads/pfSense-SA-24_03.webgui.asc', ],
      [ 'text' => 'Redmine #15263',
         'url' => 'https://redmine.pfsense.org/issues/15263', ],
      [ 'text' => 'Redmine #15264',
         'url' => 'https://redmine.pfsense.org/issues/15264', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '4e8f6cedd9c4b32b24ac3619f84e33a9a4708a29',
  'versions' => ['23.09.1', '2.7.2'],
  'descr' => 'Fix Potential XSS from jquery-treegrid unit testing files',
  'links' => [
      [ 'text' => 'Once applied, this patch may not offer a revert option' ],
      [ 'text' => 'pfSense-SA-24_04.webgui',
         'url' => 'https://docs.netgate.com/downloads/pfSense-SA-24_04.webgui.asc', ],
      [ 'text' => 'Redmine #15265',
         'url' => 'https://redmine.pfsense.org/issues/15265', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'statepolicy',
  'versions' => ['23.09.1', '2.7.2'],
  'descr' => 'Add State Policy Global Option and per-rule option.',
  'links' => [
      [ 'text' => 'Default remains floating in this patch, must opt into if-bound behavior' ],
      [ 'text' => 'Trigger a filter reload after applying to activate' ],
      [ 'text' => 'Interface-bound states have issues in PF with reply-to which can only be solved by upgrading to newer version' ],
      [ 'text' => 'Redmine #15173',
         'url' => 'https://redmine.pfsense.org/issues/15173', ],
      [ 'text' => 'Redmine #15183',
         'url' => 'https://redmine.pfsense.org/issues/15183', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '15430-23_09_1',
  'versions' => ['23.09.1', '2.7.2'],
  'descr' => 'Automatically use floating states for IPsec rules',
  'links' => [
      [ 'text' => 'After applying, reload the filter or reboot.' ],
      [ 'text' => 'Redmine #15430',
         'url' => 'https://redmine.pfsense.org/issues/15430', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '15606',
  'versions' => ['24.03', '23.09.1', '2.7.2'],
  'descr' => 'Automatically use floating states on IPsec VTI',
  'links' => [
      [ 'text' => 'After applying, reload the filter or reboot.' ],
      [ 'text' => 'Redmine #15606',
         'url' => 'https://redmine.pfsense.org/issues/15606', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '7d87d7cbce1bf6f0c8a44888c640e2c29393a9cb',
  'versions' => ['23.09.1', '2.7.2'],
  'descr' => 'Fix overly lenient permissions on tmpfs RAM disk for /var',
  'links' => [
      [ 'text' => 'After applying the patch, reboot the device' ],
      [ 'text' => 'Redmine #15054',
         'url' => 'https://redmine.pfsense.org/issues/15054', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'd3929b79ff7c3f0cdf1ba3179efea05037a18d00',
  'versions' => ['23.09.1', '2.7.2'],
  'descr' => 'Fix users with Deny Config Write privilege being able to trigger some VLAN interface operations',
  'links' => [
      [ 'text' => 'Redmine #15282',
         'url' => 'https://redmine.pfsense.org/issues/15282', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '68ed289190a383795194d3499728a0f6023f8a52',
  'versions' => ['23.09.1', '2.7.2'],
  'descr' => 'Fix users with Deny Config Write privilege being able to trigger some QinQ interface operations',
  'links' => [
      [ 'text' => 'Redmine #15318',
         'url' => 'https://redmine.pfsense.org/issues/15318', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '587dcb6ae708d144023879b509a1da9dd5dd0723',
  'versions' => ['23.09.1', '2.7.2'],
  'descr' => 'Fix OpenVPN forming invalid route statements for empty local networks',
  'links' => [
      [ 'text' => 'After applying, edit/save affected entries or reboot' ],
      [ 'text' => 'Redmine #14919',
         'url' => 'https://redmine.pfsense.org/issues/14919', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '14942',
  'versions' => ['23.09.1', '2.7.2'],
  'descr' => 'Fix DNS Resolver host overrides ignoring all aliases if first entry had a domain set but no hostname',
  'links' => [
      [ 'text' => 'Redmine #14942',
         'url' => 'https://redmine.pfsense.org/issues/14942', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '216df8ac250e2fe705c90f07c2a5e1811e7011e9',
  'versions' => ['23.09.1', '2.7.2'],
  'descr' => 'Fix Kea handling of FQDN entries for NTP servers, add input validation to prevent them from being added',
  'links' => [
      [ 'text' => 'Redmine #14991',
         'url' => 'https://redmine.pfsense.org/issues/14991', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'faf9f096448c3d18ba291901e391270036ab47c7',
  'versions' => ['23.09.1', '2.7.2'],
  'descr' => 'Fix Kea DHCP PHP error from WINS server value',
  'links' => [
      [ 'text' => 'Redmine #14996',
         'url' => 'https://redmine.pfsense.org/issues/14996', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '48aea6ee7e03b5b7f49dd143bd1993d33ba74f5b',
  'versions' => ['23.09.1', '2.7.2'],
  'descr' => 'Fix removing an IPsec Phase 1 entry either removing the wrong Phase 2 entries or leaving orphaned Phase 2 entries in the configuration',
  'links' => [
      [ 'text' => 'Redmine #15171',
         'url' => 'https://redmine.pfsense.org/issues/15171', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '88670c6c167418e7d12b010c0ce8b7d06c2b757f',
  'versions' => ['23.09.1', '2.7.2'],
  'descr' => 'Fix reordering IPsec Phase 2 entries resulting in a malformed configuration',
  'links' => [
      [ 'text' => 'If this patch offers both Apply and Revert actions, do not Revert' ],
      [ 'text' => 'Redmine #15384',
         'url' => 'https://redmine.pfsense.org/issues/15384', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '7b920960e5f38aedd35316c762c5b0b6dbc84c60',
  'versions' => ['23.09.1', '2.7.2'],
  'descr' => 'Fix a PHP error when generating a notification after detecting a malformed configuration',
  'links' => [
      [ 'text' => 'Redmine #15157',
         'url' => 'https://redmine.pfsense.org/issues/15157', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'ce83f38a8a51c3abe1291878420627343cf6b4a4',
  'versions' => ['23.09.1', '2.7.2'],
  'descr' => 'Fix /etc/rc.local script content being executed at login instead of during boot sequence',
  'links' => [
      [ 'text' => 'Redmine #10980',
         'url' => 'https://redmine.pfsense.org/issues/10980', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'a088d550a14074457c669d174a0237018a0bb4b1',
  'versions' => ['23.09.1', '2.7.2'],
  'descr' => 'Fix status_interfaces.php missing several values for SFP modules',
  'links' => [
      [ 'text' => 'Redmine #15112',
         'url' => 'https://redmine.pfsense.org/issues/15112', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'd53185888b7588c85a33ccfc14447335045fe5b7',
  'versions' => ['23.09.1', '2.7.2'],
  'descr' => 'Fix inability to configure dual stack IPsec tunnels to accept connections from any remote address of either address family',
  'links' => [
      [ 'text' => 'Redmine #15147',
         'url' => 'https://redmine.pfsense.org/issues/15147', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '4200-iflib-rxqs',
  'models' => ['4200'],
  'versions' => ['23.09.1', '23.09'],
  'descr' => 'Force the use of a single RX queue for increased performance on Netgate 4200 systems.',
  'links' => [
      [ 'text' => 'After applying the patch, reboot the device.' ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'terrapin-no-etm-no-chacha',
  'versions' => ['23.09.1', '23.09', '23.05.1', '23.05', '23.01', '2.7.2', '2.7.1', '2.7.0', '2.6.0'],
  'descr' => 'Workaround for Terrapin SSH Attack',
  'links' => [
      [ 'text' => 'After applying the patch, reboot or restart the SSH daemon' ],
      [ 'text' => 'FreeBSD-SA-23:19.openssh',
         'url' => 'https://www.freebsd.org/security/advisories/FreeBSD-SA-23:19.openssh.asc', ],
      [ 'text' => 'Terrapin Attack',
         'url' => 'https://terrapin-attack.com/', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'a6cf534d0fa0297547f1e587a12729f9d7066bae',
  'versions' => ['23.09'],
  'descr' => 'Fix "URL (IPs)" type Aliases not being resolved in the firewall ruleset',
  'links' => [
      [ 'text' => 'Redmine #14947',
         'url' => 'https://redmine.pfsense.org/issues/14947', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '1fbbea8f10c58ef11851662588819c654e31ceae',
  'versions' => ['23.09'],
  'descr' => 'Fix DHCP WAN with multiple IP Alias VIPs may leave 0.0.0.0 IP address on interface at boot',
  'links' => [
      [ 'text' => 'Redmine #14966',
         'url' => 'https://redmine.pfsense.org/issues/14966', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '5eb325e0def04241684b4d2c9583f8ca9d8bc05e',
  'versions' => ['23.09'],
  'descr' => 'Fix interfaces.php not saving PPP or Gateway configuration',
  'links' => [
      [ 'text' => 'Redmine #14949',
         'url' => 'https://redmine.pfsense.org/issues/14949', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '345ede29dbfad4afdf6b1d7afd73213158b41cce',
  'versions' => ['23.09', '2.7.1'],
  'descr' => 'Fix PHP Error on interfaces.php when creating a PPP interface',
  'links' => [
      [ 'text' => 'Redmine #14949',
         'url' => 'https://redmine.pfsense.org/issues/14949', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '6df70417029defed162b539720e8baa03984f653',
  'versions' => ['23.09', '2.7.1'],
  'descr' => 'Fix PHP Error in DHCPv6 Server with empty configuration section',
  'links' => [
      [ 'text' => 'Redmine #14978',
         'url' => 'https://redmine.pfsense.org/issues/14978', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'a6c6b835f8d75796c0c1fb9ecde90f5b1757f807',
  'versions' => ['23.09', '2.7.1'],
  'descr' => 'Fix incorrect DHCPv6 Relay input validation errors',
  'links' => [
      [ 'text' => 'Redmine #14965',
         'url' => 'https://redmine.pfsense.org/issues/14965', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '0fc7765c886ed60555750d12808f493d70918450',
  'versions' => ['23.09', '2.7.1'],
  'descr' => 'Fix Mobile IPsec group authentiation',
  'links' => [
      [ 'text' => 'Redmine #14963',
         'url' => 'https://redmine.pfsense.org/issues/14963', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'dcdb461733044d274c742832097b13a312045f37',
  'versions' => ['23.09', '2.7.1'],
  'descr' => 'Fix IPsec log categories set to "Audit" not functioning or saving in the GUI',
  'links' => [
      [ 'text' => 'Redmine #14990',
         'url' => 'https://redmine.pfsense.org/issues/14990', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'e573756c98d1181583fee0f7d818c6be0ea3da0e',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix CRL generation for intermediate certificate authorities',
  'links' => [
      [ 'text' => 'Save/Apply services using CRLs with intermediate CAs (or reboot) and export new copies of affected CRLs as needed' ],
      [ 'text' => 'Redmine #9889',
         'url' => 'https://redmine.pfsense.org/issues/9889', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '5082edf92795fe8266be49905fe4f07eb682449d',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix Static ARP entries not being configured at boot',
  'links' => [
      [ 'text' => 'Redmine #14374',
         'url' => 'https://redmine.pfsense.org/issues/14374', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '892de1ecdaa23b164f6b2a2251d7538eee2199ea',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix log rotation not active when configuration contains an empty syslog section',
  'links' => [
      [ 'text' => 'Redmine #14517',
         'url' => 'https://redmine.pfsense.org/issues/14517', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '6021c3e059885ce3fff09e5b00df037db034ff14',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix per-log settings for file size and retenation count not being respected',
  'links' => [
      [ 'text' => 'Redmine #14545',
         'url' => 'https://redmine.pfsense.org/issues/14545', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '77e168861ba43b3d6290df07fc04481c09174b28',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix Firewall rule bulk copy function not respecting Convert interface definitions option',
  'links' => [
      [ 'text' => 'Redmine #14576',
         'url' => 'https://redmine.pfsense.org/issues/14576', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'd536506909c89b5f42e6bf1c63cf02e723b0fb72',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix Captive Portal link to view custom HTML not working',
  'links' => [
      [ 'text' => 'Redmine #14598',
         'url' => 'https://redmine.pfsense.org/issues/14598', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '892d939ee0473992abece201ed3d5d2bfdfd276f',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix DHCPv6 Prefix Delegation not installing routes',
  'links' => [
      [ 'text' => 'Requires manual "pkg install dhcpleases6"' ],
      [ 'text' => 'Redmine #14502',
         'url' => 'https://redmine.pfsense.org/issues/14502', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '340aa54839a5b3a8fb74b66919511cebb307bb57',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix OpenVPN selecting wrong interface address when VIPs are present',
  'links' => [
      [ 'text' => 'Redmine #14646',
         'url' => 'https://redmine.pfsense.org/issues/14646', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'eab8453fd857de3352f352332896b065110313f4',
  'versions' => ['23.05.1'],
  'descr' => 'Fix Unicast CARP reverting to multicast when adding IP alias using this CARP VIP as parent',
  'links' => [
      [ 'text' => 'Redmine #14586',
         'url' => 'https://redmine.pfsense.org/issues/14586', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '543dc9253d6ab0e755ee043da2217d996a28ab5e',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix Potential XSS via PPP Provider Selection',
  'links' => [
      [ 'text' => 'Redmine #14547',
         'url' => 'https://redmine.pfsense.org/issues/14547', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'f387c974a9a597bf01ab86ec049cca186a1e050c',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix Potential XSS via Dynamic Filter Logs',
  'links' => [
      [ 'text' => 'Redmine #14548',
         'url' => 'https://redmine.pfsense.org/issues/14548', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'd69d6c8424ab4299234fb5ec6964682e2e6cbcdd',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix potential arbitrary command execution in GIF/GRE interface management',
  'links' => [
      [ 'text' => 'Redmine #14549',
         'url' => 'https://redmine.pfsense.org/issues/14549', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'f72618c4abb61ea6346938d0c93df9078736b775',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix potential arbitrary command execution in Packet Capture',
  'links' => [
      [ 'text' => 'Redmine #14809',
         'url' => 'https://redmine.pfsense.org/issues/14809', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'fcd5e10a67ac9a67cc7116ea1a314aaea225c699',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix IPsec restart in CARP event not triggering properly',
  'links' => [
      [ 'text' => 'Redmine #14738',
         'url' => 'https://redmine.pfsense.org/issues/14738', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'f106b62cfbed279e8140ffa1edf535defb0221ab',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix OpenVPN resync potentially acting on unrelated interfaces',
  'links' => [
      [ 'text' => 'Redmine #14781',
         'url' => 'https://redmine.pfsense.org/issues/14781', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '71f360de9043c64a999c6b47003099ee59a5a132',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix PHP Error viewing traffic graphs in iftop mode',
  'links' => [
      [ 'text' => 'Redmine #14500',
         'url' => 'https://redmine.pfsense.org/issues/14500', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'aad64829622356cd761062e57f4a8224d1b145e4',
  'versions' => ['2.7.0'],
  'descr' => 'Fix Logo text being partially rendered when using Compact-RED theme',
  'links' => [
      [ 'text' => 'Redmine #14807',
         'url' => 'https://redmine.pfsense.org/issues/14807', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'dcb4461336de2fe69ac173787c8bce66e93ce672',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix PHP Error with one.com Dynamic DNS Provider',
  'links' => [
      [ 'text' => 'Redmine #14649',
         'url' => 'https://redmine.pfsense.org/issues/14649', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'ddb57f79e26e97e2a22f701016fc70a7d1c09ce4',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix list of Dynamic DNS Providers with split host and domain name parts missing several providers',
  'links' => [
      [ 'text' => 'Redmine #14783',
         'url' => 'https://redmine.pfsense.org/issues/14783', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '202e3c1b7d3af019f03bf2545a7f31062f8e8e08',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix PHP error in status_ipsec.php after removing an active tunnel',
  'links' => [
      [ 'text' => 'Redmine #14525',
         'url' => 'https://redmine.pfsense.org/issues/14525', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '502398beea2e0d6930a6e9d1f7fc16737f63265d',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix Captive Portal incorrectly allowing creation of voucher rolls with leading zeroes',
  'links' => [
      [ 'text' => 'Edit and save affected rolls after applying patch to correct the roll configuration' ],
      [ 'text' => 'Redmine #14325',
         'url' => 'https://redmine.pfsense.org/issues/14325', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '1a57545864783b3acc5f28d166a79bd92a849759',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix PHP Error in CSRF with invalid time value',
  'links' => [
      [ 'text' => 'Redmine #14394',
         'url' => 'https://redmine.pfsense.org/issues/14394', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '9270d777907048d2bfc31f4e57a01e915ff71a88',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix copying a user group does not work for first entry in list',
  'links' => [
      [ 'text' => 'Redmine #14695',
         'url' => 'https://redmine.pfsense.org/issues/14695', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '17630ffa48e33def331a65ee50f1ba1d2c3a5de5',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix crash dumps not being recovered properly on systems with multiple swap partitions (e.g. ZFS mirrored disks)',
  'links' => [
      [ 'text' => 'Redmine #14767',
         'url' => 'https://redmine.pfsense.org/issues/14767', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '57e299906c4525bcc89c728a6246495369178023',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix GUI TCP port not being updated when left blank',
  'links' => [
      [ 'text' => 'Redmine #14820',
         'url' => 'https://redmine.pfsense.org/issues/14820', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '3c8a408116c01d74fd114d8cc143b0f550bf00c5',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix update check in GUI not honoring proxy settings',
  'links' => [
      [ 'text' => 'Redmine #14609',
         'url' => 'https://redmine.pfsense.org/issues/14609', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '93f8b28797a2b618f96589c916128019231f027e-plus',
  'versions' => ['23.05.1'],
  'descr' => 'Add Intel Speed Shift options',
  'links' => [
      [ 'text' => 'Redmine #14047',
         'url' => 'https://redmine.pfsense.org/issues/14047', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '93f8b28797a2b618f96589c916128019231f027e',
  'versions' => ['2.7.0'],
  'descr' => 'Add Intel Speed Shift options',
  'links' => [
      [ 'text' => 'Redmine #14047',
         'url' => 'https://redmine.pfsense.org/issues/14047', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'd6078e851ade476b6e9190fd77b9a70eb3c7bb92',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Add option to invalidate GUI login sessions if client IP address changes',
  'links' => [
      [ 'text' => 'Redmine #14265',
         'url' => 'https://redmine.pfsense.org/issues/14265', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '28e2b61100b0f1cf81de5e73fd579bb6bd36afb5',
  'versions' => ['23.05.1', '2.7.0'],
  'descr' => 'Fix ctype_xdigit result is invalid for values <= 255',
  'links' => [
      [ 'text' => 'Redmine #14702',
         'url' => 'https://redmine.pfsense.org/issues/14702', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '217f42ec30a4008907ac6fbb65b7b2e0ebf51eb9',
  'versions' => ['23.05'],
  'descr' => 'Fix alias bulk import breaking configuration',
  'links' => [
      [ 'text' => 'Redmine #14412',
         'url' => 'https://redmine.pfsense.org/issues/14412', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'a99c03dde3df7053747ec61607c0fb2e2c0a7d22',
  'versions' => ['23.05', '23.01'],
  'descr' => 'Fix Outbound NAT &quot;Other Subnet&quot; Translation address input validation',
  'links' => [
      [ 'text' => 'Redmine #14354',
         'url' => 'https://redmine.pfsense.org/issues/14354', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'ea79a4fe5707898fff89e80d7252e5c84fca7dd4',
  'versions' => ['23.05', '23.01'],
  'descr' => 'Fix IPv6 over IPv4 tunneling PF ruleset error',
  'links' => [
      [ 'text' => 'Redmine #14415',
         'url' => 'https://redmine.pfsense.org/issues/14415', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '073a6baceffc4a363eac9369cc036fc7b19b919e',
  'versions' => ['23.05'],
  'descr' => 'Fix GUI Max Processes value not saving',
  'links' => [
      [ 'text' => 'Redmine #14425',
         'url' => 'https://redmine.pfsense.org/issues/14425', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'c13bf6d4d174d77768d9090e97b3379835495356',
  'versions' => ['23.05'],
  'descr' => 'Fix missing ngeth interfaces triggering reassignment',
  'links' => [
      [ 'text' => 'Redmine #14410',
         'url' => 'https://redmine.pfsense.org/issues/14410', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '87d2b7464311c1f94b827a38502260e2e5a23e08',
  'versions' => ['23.05'],
  'descr' => 'Fix Captive Portal PHP error when processing used MACs',
  'links' => [
      [ 'text' => 'Redmine #14446',
         'url' => 'https://redmine.pfsense.org/issues/14446', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'c5b8e57aa51ff82b45bd6cb925ba512f4c01dcba',
  'versions' => ['23.01', '22.05.1', '22.05', '2.6.0'],
  'descr' => 'Fix potential arbitrary command execution in interfaces_bridge_edit.php from bridge interface names',
  'links' => [
      [ 'text' => 'pfSense-SA-23_06.webgui',
         'url' => 'https://docs.netgate.com/downloads/pfSense-SA-23_06.webgui', ],
      [ 'text' => 'Redmine #14281',
         'url' => 'https://redmine.pfsense.org/issues/14281', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '66b989e824042c0cf5e75b1cb245b0ae13548949',
  'versions' => ['23.01'],
  'descr' => 'Fix interface name / dynamic gateway names not using upper case',
  'links' => [
      [ 'text' => 'Redmine #14057',
         'url' => 'https://redmine.pfsense.org/issues/14057', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '18b8e41591905844627377b76347f8acba88f0a1',
  'versions' => ['23.01'],
  'descr' => 'Refresh linker hints at boot/Fix 3100 OpenVPN/GIF failures',
  'links' => [
      [ 'text' => 'Requires reboot to activate' ],
      [ 'text' => 'Redmine #13963',
         'url' => 'https://redmine.pfsense.org/issues/13963', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '37c29e4de148a14480c01c8fa179e9b630bb0fb4',
  'versions' => ['23.01'],
  'descr' => 'Disable sendfile in nginx to avoid a possible panic with unmapped mbufs',
  'links' => [
      [ 'text' => 'Requires reboot to activate' ],
      [ 'text' => 'Redmine #13938',
         'url' => 'https://redmine.pfsense.org/issues/13938', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'ff715efce5e6c65b3d49dc2da7e1bdc437ecbf12',
  'versions' => ['23.01'],
  'descr' => 'Disable unnecessary default FreeBSD cron jobs which can lead to increased RAM/ARC usage',
  'links' => [
      [ 'text' => 'Requires reboot to activate' ],
      [ 'text' => 'Redmine #14016',
         'url' => 'https://redmine.pfsense.org/issues/14016', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '0d83ed084a987f3446a0cbdcf249fc5b8722726f',
  'versions' => ['23.01'],
  'descr' => 'Update memory graphing to match current FreeBSD behavior.',
  'links' => [
      [ 'text' => 'Requires reboot to activate' ],
      [ 'text' => 'Redmine #14011',
         'url' => 'https://redmine.pfsense.org/issues/14011', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '46b159032fef8c78783aa1a749d2238cfed7ac0d',
  'versions' => ['23.01'],
  'descr' => 'Fix DNS Resolver missing automatic ACLs for local IPv6 when bound to All',
  'links' => [
      [ 'text' => 'Redmine #13851',
         'url' => 'https://redmine.pfsense.org/issues/13851', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'e53f0573d853325dfb463eab8bfe59a9f4d6ce61',
  'versions' => ['23.01'],
  'descr' => 'Fix obtaining DNS servers from PPP WAN',
  'links' => [
      [ 'text' => 'Redmine #13962',
         'url' => 'https://redmine.pfsense.org/issues/13962', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'cf2a2f82c2aa551b26a6d9606d5e6da1e760ff6b',
  'versions' => ['23.01'],
  'descr' => 'Fix PHP error on Interface Status page from PPP historical uptime calculation',
  'links' => [
      [ 'text' => 'Redmine #14117',
         'url' => 'https://redmine.pfsense.org/issues/14117', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '5841d5850265476100b719e60e38b65887cd1460',
  'versions' => ['23.01'],
  'descr' => 'Fix PHP error on Interface Status page from certain Switch+VLAN configuration combinations',
  'links' => [
      [ 'text' => 'Redmine #13981',
         'url' => 'https://redmine.pfsense.org/issues/13981', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'a56e018238c5c46bf3a93b647ece6e7a4538380a',
  'versions' => ['23.01'],
  'descr' => 'Fix Netgate 1100 Status LEDs',
  'links' => [
      [ 'text' => 'NG 10085' ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'fed25589f4eba4ac6293fec7135f0078c03dfb62',
  'versions' => ['23.01'],
  'descr' => 'Fix IPsec widget settings change erasing widget layout',
  'links' => [
      [ 'text' => 'Redmine #14053',
         'url' => 'https://redmine.pfsense.org/issues/14053', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '404efa211294c85fa497b756d494d41f1b0f658d',
  'versions' => ['23.01'],
  'descr' => 'Fix PHP errors in AutoConfigBackup',
  'links' => [
      [ 'text' => 'Redmine #14076',
         'url' => 'https://redmine.pfsense.org/issues/14076', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '2186435b5185ceb294cd6a4c1380db443e4dd218',
  'versions' => ['23.01'],
  'descr' => 'Fix automatic firewall rules for HA DHCP server failover',
  'links' => [
      [ 'text' => 'Requires reboot or filter reload to activate' ],
      [ 'text' => 'Redmine #13965',
         'url' => 'https://redmine.pfsense.org/issues/13965', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'd9fa4584e3fb63d6051e9f1db7655f931cb1be19',
  'versions' => ['23.01'],
  'descr' => 'Fix RRD processing of state data and re-enable NAT on States graph',
  'links' => [
      [ 'text' => 'Requires reboot to activate' ],
      [ 'text' => 'Redmine #13966',
         'url' => 'https://redmine.pfsense.org/issues/13966', ],
      [ 'text' => 'Redmine #13969',
         'url' => 'https://redmine.pfsense.org/issues/13969', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'd015b45a395045a56b9190f284459a6a4cc57568',
  'versions' => ['23.01'],
  'descr' => 'Fix custom state timeout defaults not being respected',
  'links' => [
      [ 'text' => 'Requires reboot or filter reload to activate' ],
      [ 'text' => 'Redmine #13992',
         'url' => 'https://redmine.pfsense.org/issues/13992', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '0e847960910ae9f14ca7b52c84be25fe4b9d1064',
  'versions' => ['23.01'],
  'descr' => 'Fix PHP errors in NTP status and widget',
  'links' => [
      [ 'text' => 'Redmine #13999',
         'url' => 'https://redmine.pfsense.org/issues/13999', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '060f50552e63f4ef73cd08eed329691010632b8d',
  'versions' => ['23.01'],
  'descr' => 'Fix handling of DHCPv6 priority tag on PF rules',
  'links' => [
      [ 'text' => 'Requires reboot or filter reload to activate' ],
      [ 'text' => 'Redmine #14010',
         'url' => 'https://redmine.pfsense.org/issues/14010', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '290b3461bb816e9fc161568e499d43b24542cb9f',
  'versions' => ['23.01'],
  'descr' => 'Fix PHP Error in Alias bulk import function',
  'links' => [
      [ 'text' => 'Redmine #14013',
         'url' => 'https://redmine.pfsense.org/issues/14013', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '4342d179afe732baf3a73e2db4381b57b1aa7703',
  'versions' => ['23.01'],
  'descr' => 'Fix default sorting of Aliases in lists',
  'links' => [
      [ 'text' => 'Redmine #14015',
         'url' => 'https://redmine.pfsense.org/issues/14015', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '4342d179afe732baf3a73e2db4381b57b1aa7703.p2',
  'versions' => ['23.01'],
  'descr' => 'Fix default sorting of Aliases in lists (part 2)',
  'links' => [
      [ 'text' => 'Redmine #14015',
         'url' => 'https://redmine.pfsense.org/issues/14015', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '9bfd89747eba77091ab6e2df5639a33a185342f8',
  'versions' => ['23.01'],
  'descr' => 'Fix PHP error during XMLRPC HA Sync with empty VIP section',
  'links' => [
      [ 'text' => 'Redmine #14034',
         'url' => 'https://redmine.pfsense.org/issues/14034', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '24c0f00ff82d78c1e5301e43df21c2ef8ebecf7f',
  'versions' => ['23.01'],
  'descr' => 'Fix PHP errors from upgrading IPsec tunnels containing only deprecated encryption options',
  'links' => [
      [ 'text' => 'Redmine #14009',
         'url' => 'https://redmine.pfsense.org/issues/14009', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'be6d44179f8a82b7adbdf95336d68ee491963ae0',
  'versions' => ['23.01'],
  'descr' => 'Fix PHP Error when attempting to add EasyRule for ICMPv6 log entries',
  'links' => [
      [ 'text' => 'Redmine #14037',
         'url' => 'https://redmine.pfsense.org/issues/14037', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'fae6b2c014749b3f56e03b3ea7e51ecee2cf53be',
  'versions' => ['23.01'],
  'descr' => 'Fix PHP Errors from empty DHCP/DHCPv6 server configuration entries',
  'links' => [
      [ 'text' => 'Redmine #13983',
         'url' => 'https://redmine.pfsense.org/issues/13983', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'f884cc204872957e7729b48e929b6be9ddd711eb',
  'versions' => ['23.01'],
  'descr' => 'Correct PF fragment disassembly disable syntax',
  'links' => [
      [ 'text' => 'Requires reboot or filter reload to activate' ],
      [ 'text' => 'Redmine #14098',
         'url' => 'https://redmine.pfsense.org/issues/14098', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '4fe6481fa35f31b93ed5841c3342cbb5bd76237c',
  'versions' => ['23.01'],
  'descr' => 'Re-enable console bell by default and add GUI option to enable/disable',
  'links' => [
      [ 'text' => 'Requires reboot to activate' ],
      [ 'text' => 'Redmine #14002',
         'url' => 'https://redmine.pfsense.org/issues/14002', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'c5faa351c1ef6d4555478a7f50b3a16ece7e0b2a',
  'versions' => ['23.01'],
  'descr' => 'Fix SMTP notification loop / config.cache write failures',
  'links' => [
      [ 'text' => 'Redmine #14031',
         'url' => 'https://redmine.pfsense.org/issues/14031', ],
      [ 'text' => 'Redmine #14061',
         'url' => 'https://redmine.pfsense.org/issues/14061', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '8b962c6a752a654f2def293d93c102d2d20a6887',
  'versions' => ['23.01'],
  'descr' => 'Fix PHP errors in system log settings',
  'links' => [
      [ 'text' => 'Redmine #13942',
         'url' => 'https://redmine.pfsense.org/issues/13942', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '13915',
  'versions' => ['23.01'],
  'descr' => 'Fix PHP errors in Traffic Shaper Wizards',
  'links' => [
      [ 'text' => 'Redmine #13915',
         'url' => 'https://redmine.pfsense.org/issues/13915', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '14283',
  'versions' => ['23.01'],
  'descr' => 'Fix system logs not containing any data when the configuration has an empty or missing syslog section',
  'links' => [
      [ 'text' => 'Requires reboot or manual restart of system logging to activate' ],
      [ 'text' => 'Redmine #14283',
         'url' => 'https://redmine.pfsense.org/issues/14283', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '13936',
  'versions' => ['23.01'],
  'descr' => 'Fix PHP errors when processing empty RRD files',
  'links' => [
      [ 'text' => 'Redmine #13936',
         'url' => 'https://redmine.pfsense.org/issues/13936', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '82364513c64f0233617a356b62a461b6eba253f3',
  'versions' => ['23.01'],
  'descr' => 'Fix PHP error in NTP settings if the configuration contains unmigrated data from openntpd',
  'links' => [
      [ 'text' => 'Redmine #14033',
         'url' => 'https://redmine.pfsense.org/issues/14033', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '0ba1a7ec7871f8f6bd240a08f238a2fb1ecba16b',
  'versions' => ['23.01'],
  'descr' => 'Fix SSL/TLS OpenVPN clients failing to start when configured with a Tunnel Network',
  'links' => [
      [ 'text' => 'Redmine #13350',
         'url' => 'https://redmine.pfsense.org/issues/13350', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '02af3d3efedacf511ebe834667fa7c707b46b43c',
  'versions' => ['23.01'],
  'descr' => 'Fix PHP errors during certain IPv6 prefix check operations',
  'links' => [
      [ 'text' => 'Redmine #14256',
         'url' => 'https://redmine.pfsense.org/issues/14256', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '14035',
  'versions' => ['23.01'],
  'descr' => 'Fix PHP errors when attempting to create a GIF interface on ARM systems',
  'links' => [
      [ 'text' => 'Redmine #14035',
         'url' => 'https://redmine.pfsense.org/issues/14035', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '528e53e8bb86642e38aa098226f5b74951d6a7bb',
  'versions' => ['2.6.0'],
  'descr' => 'Fix potential XSS from URL and URL Table alias URLs',
  'links' => [
      [ 'text' => 'pfSense-SA-22_05.webgui',
         'url' => 'https://docs.netgate.com/downloads/pfSense-SA-22_05.webgui', ],
      [ 'text' => 'Redmine #13060',
         'url' => 'https://redmine.pfsense.org/issues/13060', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '611de84ae2d1e65217dbccb7e9db32a019bd8d97',
  'versions' => ['2.6.0', '22.05'],
  'descr' => 'Fix potential XSS on browser.php from unencoded filenames',
  'links' => [
      [ 'text' => 'pfSense-SA-23_01.webgui',
         'url' => 'https://docs.netgate.com/downloads/pfSense-SA-23_01.webgui', ],
      [ 'text' => 'Redmine #13262',
         'url' => 'https://redmine.pfsense.org/issues/13262', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'e9c53ad9b35ff152d2b76b8fcbb0a94adc809124',
  'versions' => ['22.05.1'],
  'descr' => 'Fix potential XSS on browser.php from unencoded filenames',
  'links' => [
      [ 'text' => 'pfSense-SA-23_01.webgui',
         'url' => 'https://docs.netgate.com/downloads/pfSense-SA-23_01.webgui', ],
      [ 'text' => 'Redmine #13262',
         'url' => 'https://redmine.pfsense.org/issues/13262', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '7c54d26e60fe524df63277da77c07e995bc3b351',
  'versions' => ['2.6.0', '22.05'],
  'descr' => 'Fix potential XSS from CA and Certificate descriptions',
  'links' => [
      [ 'text' => 'pfSense-SA-23_02.webgui',
         'url' => 'https://docs.netgate.com/downloads/pfSense-SA-23_02.webgui', ],
      [ 'text' => 'CVE-2022-37417', ],
      [ 'text' => 'Redmine #13387',
         'url' => 'https://redmine.pfsense.org/issues/13387', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '6dc0750874b69373f8adbae9b0af223af13f5f4a',
  'versions' => ['2.6.0', '22.05'],
  'descr' => 'Fix potential arbitrary file create from invalid URL Table alias names',
  'links' => [
      [ 'text' => 'pfSense-SA-23_03.webgui',
         'url' => 'https://docs.netgate.com/downloads/pfSense-SA-23_03.webgui', ],
      [ 'text' => 'Redmine #13425',
         'url' => 'https://redmine.pfsense.org/issues/13425', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '208134113d92d809d4f0e686f3817274854ff264',
  'versions' => ['22.05.1'],
  'descr' => 'Fix PHP error in URL Table Alias validation',
  'links' => [
      [ 'text' => 'pfSense-SA-23_03.webgui',
         'url' => 'https://docs.netgate.com/downloads/pfSense-SA-23_03.webgui', ],
      [ 'text' => 'Redmine #13425',
         'url' => 'https://redmine.pfsense.org/issues/13425', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '22f7276c167210f644cf586704ec21da22002bb2',
  'versions' => ['2.6.0', '22.05'],
  'descr' => 'Fix potential arbitrary command execution via status.php from unencoded filenames',
  'links' => [
      [ 'text' => 'pfSense-SA-23_04.webgui',
         'url' => 'https://docs.netgate.com/downloads/pfSense-SA-23_04.webgui', ],
      [ 'text' => 'Redmine #13426',
         'url' => 'https://redmine.pfsense.org/issues/13426', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '70bfd0fda18012a01547a4eeff17c22c0adf8503',
  'versions' => ['2.6.0', '22.05', '22.05.1'],
  'descr' => 'Fix sshguard login protection bypass from GUI authentication attempts with proxy headers',
  'links' => [
      [ 'text' => 'pfSense-SA-23_05.sshguard',
         'url' => 'https://docs.netgate.com/downloads/pfSense-SA-23_05.sshguard', ],
      [ 'text' => 'Redmine #13574',
         'url' => 'https://redmine.pfsense.org/issues/13574', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'a3c1589086ea67d25a28ec14ab95d7fd9ab25fa2',
  'versions' => ['2.6.0', '22.01', '22.05'],
  'descr' => 'Fix for CRL expiration lifetime default and maximum values',
  'links' => [
      [ 'text' => 'Redmine #13424',
         'url' => 'https://redmine.pfsense.org/issues/13424', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '8ddf2b5a999772754080825f07acf9b6326f1f04',
  'versions' => ['2.6.0', '22.01'],
  'descr' => 'Add user preference to choose password hash algorithm',
  'links' => [
      [ 'text' => 'Redmine #12855',
         'url' => 'https://redmine.pfsense.org/issues/12855', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '3b50f7656967fbb4daa869a7ae6d18bc5ab6eec3',
  'versions' => ['2.6.0', '22.01'],
  'descr' => 'Add UPnP NAT Anchors to fix outbound NAT for multiple consoles.',
  'links' => [
      [ 'text' => 'Redmine #7727',
         'url' => 'https://redmine.pfsense.org/issues/7727#note-75', ],
      [ 'text' => 'Forum Thread',
         'url' => 'https://forum.netgate.com/topic/169837/upnp-fix-for-multiple-clients-consoles-playing-the-same-game', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '12827workaround',
  'versions' => ['2.6.0', '22.01'],
  'descr' => 'Disable pf counter data preservation to temporarily work around latency when reloading large rulesets',
  'links' => [
      [ 'text' => 'Redmine #12827',
         'url' => 'https://redmine.pfsense.org/issues/12827', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'fd30b9eda98900eb5f1a0c37d600ef4deaf582ad',
  'versions' => ['2.6.0', '22.01'],
  'descr' => 'Fix Captive Portal handling of non-TCP traffic after login',
  'links' => [
      [ 'text' => 'Redmine #12834',
         'url' => 'https://redmine.pfsense.org/issues/12834', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'bdffb77d1aa21770b23ef408ad9fba79d0825ec5',
  'versions' => ['2.6.0', '22.01'],
  'descr' => 'Fix Dynamic DNS hang on Save and Force Update',
  'links' => [
      [ 'text' => 'Redmine #12870',
         'url' => 'https://redmine.pfsense.org/issues/12870', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '4612721800a1b25bb1fb2d4d7c4ceea6f44f208e',
  'versions' => ['2.6.0', '22.01'],
  'descr' => 'Fix Namecheap Dynamic DNS response processing',
  'links' => [
      [ 'text' => 'Redmine #12816',
         'url' => 'https://redmine.pfsense.org/issues/12816', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'b5360f49fb3c1fdc36ebf13c20b68d4ff1e15fe6',
  'versions' => ['2.6.0', '22.01'],
  'descr' => 'Fix Google Domains Dynamic DNS response processing',
  'links' => [
      [ 'text' => 'Redmine #12754',
         'url' => 'https://redmine.pfsense.org/issues/12754', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '3ade222beb2cae2c0681ed69d4e5a0c82c6303f9',
  'versions' => ['2.6.0', '22.01'],
  'descr' => 'Fix OpenVPN dashboard widget client termination',
  'links' => [
      [ 'text' => 'Redmine #12817',
         'url' => 'https://redmine.pfsense.org/issues/12817', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'b2fce958b8a2e80754b49eb3d17795757df6a76c',
  'versions' => ['22.01'],
  'descr' => 'Fix Netgate 5100 status LED',
  'links' => [
      [ 'text' => 'NG 7538' ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'c416f6fab10f149b15a352dfb609f86a98f6103d',
  'versions' => ['2.5.2'],
  'descr' => 'Additional fix for XSS in captive portal redirect URL handling',
  'links' => [
      [ 'text' => 'pfSense-SA-21_02.webgui',
         'url' => 'https://docs.netgate.com/downloads/pfSense-SA-21_02.captiveportal.asc', ],
      [ 'text' => 'Redmine #11843',
         'url' => 'https://redmine.pfsense.org/issues/11843', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'bf21f67bbe2d1694ad1ad72728623dded9ace426',
  'versions' => ['2.5.2', '21.05.2'],
  'descr' => 'Fix file overwrite vulnerability in services_ntpd_gps.php',
  'links' => [
      [ 'text' => 'pfSense-SA-22_01.webgui',
         'url' => 'https://docs.netgate.com/downloads/pfSense-SA-22_01.webgui.asc', ],
      [ 'text' => 'Redmine #12191',
         'url' => 'https://redmine.pfsense.org/issues/12191', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '72ea2b69cc111d4bc8ebf1ccf1e1529923c5b88a',
  'versions' => ['2.5.2', '21.05.2'],
  'descr' => 'Fix multiple vulnerabilities in diag_routes.php data collection',
  'links' => [
      [ 'text' => 'pfSense-SA-22_02.webgui',
         'url' => 'https://docs.netgate.com/downloads/pfSense-SA-22_02.webgui.asc', ],
      [ 'text' => 'Redmine #12257',
         'url' => 'https://redmine.pfsense.org/issues/12257', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => '78ce96a9af3b2ab5159ef6623078bfc4b15f8a89',
  'versions' => ['2.5.2', '21.05.2'],
  'descr' => 'Fix OpenVPN form validation',
  'links' => [
      [ 'text' => 'pfSense-SA-22_03.webgui',
         'url' => 'https://docs.netgate.com/downloads/pfSense-SA-22_03.webgui.asc', ],
      [ 'text' => 'Redmine #12677',
         'url' => 'https://redmine.pfsense.org/issues/12677', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'a9bdbd97984ff2ddefbceb2fe062fbe3a1c42d88',
  'versions' => ['2.5.2', '21.05.2'],
  'descr' => 'Fix potential XSS in pkg.php',
  'links' => [
      [ 'text' => 'pfSense-SA-22_04.webgui',
         'url' => 'https://docs.netgate.com/downloads/pfSense-SA-22_04.webgui.asc', ],
      [ 'text' => 'Redmine #12725',
         'url' => 'https://redmine.pfsense.org/issues/12725', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
],
[
  'uniqid' => 'afcc0e9c97c1993ae6b95f886665fcb4375d26c7',
  'versions' => ['2.5.2', '21.05.2'],
  'descr' => 'Disable pcscd service by default',
  'links' => [
      [ 'text' => 'Redmine #11933',
         'url' => 'https://redmine.pfsense.org/issues/11933', ],
  ],
  'basedir' => '/',
  'pathstrip' => 2,
  'ignorewhitespace' => true,
]
];
